function [lkz,mkz,er]=bk(w,a,rho,ns)
% BK - The Blanchard-Khan (1980) algorithm
%
% Implemented in MATLAB 5 by Marco Maffezzoli, (c) 7/1999
%
% Error codes: er=1: the modal matrix is singular
%              er=2: not enough stable eigenvalues
%              er=3: too many stable eigenvalues
%

nt=size(w,1);		
nl=nt-ns;
nn=size(rho,1);
w11=w(1:ns,1:ns);
w12=w(1:ns,ns+1:nt);

[evec,eval]=eig(w);
[mu1,ind]=sort(abs(diag(eval)));
mu=diag(eval);
mu=mu(ind);
p=evec(:,ind);

if rank(p)<nt
   er=1;
elseif any(abs(mu(1:ns))>=1)
   er=2;
elseif any(abs(mu(ns+1:nt))<=1)
   er=3;
else
   er=0;
end;   

if er==0

   mu2=diag(mu(ns+1:nt));
   ps=p\eye(size(p));
   b=ps*a;
   d1=mu2\eye(size(mu2));
   d2=d1*b(ns+1:nt,:);
   lee=-(eye(nl*nn)-kron(rho',d1))\d2(:);
   lee=reshape(lee,nl,nn);
   lk=-ps(ns+1:nt,ns+1:nt)\ps(ns+1:nt,1:ns);
   lz=ps(ns+1:nt,ns+1:nt)\lee;
   lkz=[lk,lz];
   mkz=[w11+w12*lk,w12*lz+a(1:ns,:);zeros(nn,ns),rho];
      
else

   lkz=0;
   mkz=0;
   
end;