%  Variables' names:

name=['K ';'B ';'A ';'E ';'C ';'Y ';'I ';'P ';'r ';'L '];

%  Variables' position:

kp=1;
bp=2;
ap=3;
ep=4;
cp=5;
yp=6;
ip=7;
pp=8;
rp=9;
lp=10;

%  Dimension of relevant vectors:

nc=1;                   % control vector
ns=2;                  	% state vector
nl=3;			% costate vector
nn=2;                  	% exogenous state vector
nxf=2;               	% auxiliary vars vector
nvar=ns+nl+nc+nn+nxf;
nt=nl+ns;

%  Parameterization:

mu=2;
sn=0.60;
sc=0.75;
g=1.004;
rky=3.32*4;
rmy=5.3*4;
eta=1.013;
rho=[0.95 0;0 0.49];

lmat=zeros(ns+nn);            % Loading matrix.
lmat(ns+1:ns+nn,ns+1:ns+nn)=[1 0;0 1];

%  Steady-state values:

sk=1-sn;
si=1-sc;
d=1-g+si/rky;
be=g/(sk/rky+1-d);
r=(g-be)/be;
theta=((eta-be)/be)*(rmy/sc)^mu;
capd=g/be*rky/sk;
vphi=(1-be)/((eta-1)*g*be);
rby=(eta-1)*rmy*((g*be)/(1-be));

yss=rky^(sk/sn);
kss=rky*yss;
bss=rby*yss;
css=sc*yss;
iss=si*yss;
lss=css^(-mu);
pss=((eta/be-1)*(lss/theta))^(1/mu);

steady=[kss;bss;1;eta;css;yss;iss;pss;r;lss];

% System matrices:

muu=-mu;
mus=[0,0,0,0,1];
mue=[0,0];
ms0=[-sn,0,0,0,capd;...
     0,0,mu*(1-be/eta)-1,0,be/eta;...
     0,0,0,r/(1+r),1;...
     g*rky,0,0,0,0;...
     0,g,0,0,0];
ms1=[0,0,0,0,-capd;...
     0,0,1,0,-1;...
     0,0,0,0,-1;...
     -(1-d)*rky-sk,0,0,0,0;...
     0,-g/be,(1-eta)*vphi,-r,0];
mu0=[0;0;0;0;0];
mu1=[0;0;0;-sc;0];
me0=[-1,0;0,0;0,0;0,0;0,0];
me1=[0,0;0,1;0,0;1,0;0,-eta*vphi];
fvu=[0;-sc/si];
fvv=[sk,0,1,0;sk/si,0,1/si,0];
fvl=[0,0,0;0,0,0];